@@ -44,14 +44,18 @@ def convert(json_file, remove_background=False, duration_format=False, deduplica
                         error_msg_len = 0
                         for i in range(0, len(error_msg)):
                             if i == len(error_msg) - 1:
-                                error_msg[i] = error_msg[i] + "\n"
+                                error_msg[i] = error_msg[i] + ' \n'
                             else:
-                                error_msg[i] = error_msg[i] + "\n\t"
+                                error_msg[i] = error_msg[i] + ' \n\t'
                             error_msg_len += len(error_msg[i])
+                        logger.error(error_msg)
                         logger.info(f'len(error_message):{error_msg_len}')
-                        item["result"]["error_message"] = str((str(error_msg).replace("\"", "").replace("\\'", ""))[:error_msg_len])#.split("[")[1].split("]")[0]
+                        error_msg_info = str(
+                            (str(error_msg).replace("\"", "").replace("\\'", "").replace("\'", ""))[
+                            :5000])  # .split("[")[1].split("]")[0]
                         # item["result"]["error_message"] = str((str(error_msg))[:len(error_msg)]).split("[")[1].split("]")[
                         #     0].replace("',", "").replace("'","")
+                        item["result"]["error_message"] = r'{}'.format(error_msg_info)
                         print(item["result"]["error_message"])
                         logger.info(f'错误信息输出:{item["result"]["error_message"]}')
                     if 'duration' in item["result"] and duration_format:
